#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME=$(uci get motioneye.@motioneye[0].image_name 2>/dev/null)
}

do_install_detail() {
  local config=`uci get motioneye.@motioneye[0].config_path 2>/dev/null`
  local port=`uci get motioneye.@motioneye[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get motioneye.@motioneye[0].image_name 2>/dev/null`

  LAN_IP=$(uci get network.lan.ipaddr)
  LAN_IP="${LAN_IP%/*}"

  if [ -z "$config" ]; then
    echo "config path is empty!"
    exit 1
  fi

  [ -z "$port" ] && port=8808
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=ccrisan/motioneye

  rm -R /opt/docker2/compose/motioneye-app
  mkdir /opt/docker2/compose/motioneye-app

  touch /opt/docker2/compose/motioneye-app/docker-compose.yml
  cat > /opt/docker2/compose/motioneye-app/docker-compose.yml <<EOF
version: "3.7"
services:
  motioneye:
    image: ${IMAGE_NAME}
    init: true
    ports:
      - "${LAN_IP}:8081:8081"
      - "${LAN_IP}:${port}:8765"
    environment:
      - TZ=Europe/Berlin
    restart: unless-stopped
    volumes:
      - ${config}:/etc/motioneye
      - /opt/docker2/compose/motioneye-app/var_lib/motioneye/var_lib:/var/lib/motioneye
    labels:
      plugsy.name: "Motioneye"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/material-outlined/Visibility"
      plugsy.link: "http://${LAN_IP}:${port}"
EOF

  docker-compose -f /opt/docker2/compose/motioneye-app/docker-compose.yml up -d

  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu
}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install motioneye"
  echo "      upgrade                Upgrade motioneye"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart motioneye"
  echo "      status                 motioneye status"
  echo "      port                   motioneye port"
}

case ${ACTION} in
  "install"|"upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    get_image
    CONTAINER_IDS=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.ID}}')
    echo "Stopping and removing containers..."
    for ID in $CONTAINER_IDS; do
      docker stop $ID
      docker rm $ID
    done
    docker rmi -f $IMAGE_NAME
  ;;
  "start"|"stop"|"restart")
    get_image
    CONTAINER_IDS=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.ID}}')
    for ID in $CONTAINER_IDS; do
      docker ${ACTION} ${ID}
    done
  ;;
  "status")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Status}}'
  ;;
  "port")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac

